==> haskell-monad-par-extras-0.3.3-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-LOTHFoXClGM78sH6EPozOx
key: monad-par-extras-0.3.3-LOTHFoXClGM78sH6EPozOx
license: BSD-3-Clause
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton, Simon Marlow
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
abi: 063b0d4ed7ec05ec40be35731696a1a1
exposed: True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State
hidden-modules: Control.Monad.Par.Pedigree
import-dirs: /usr/lib/ghc-8.6.3/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-LOTHFoXClGM78sH6EPozOx
depends:
    abstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj base-4.12.0.0
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT deepseq-1.4.4.0 mtl-2.2.2
    random-1.1-3ypV4EIycgb35PKjTYYr5q transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-IYaP7tDu7QC3qifVidMKSY
key: monad-par-extras-0.3.3-IYaP7tDu7QC3qifVidMKSY
license: BSD-3-Clause
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton, Simon Marlow
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
abi: 2058a5b310589071805bd948a2d089e4
exposed: True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State
hidden-modules: Control.Monad.Par.Pedigree
import-dirs: /usr/lib/ghc-8.6.4/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-IYaP7tDu7QC3qifVidMKSY
depends:
    abstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj base-4.12.0.0
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT deepseq-1.4.4.0 mtl-2.2.2
    random-1.1-3ypV4EIycgb35PKjTYYr5q transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
